TEST, REDECARD, AMEX, CIELO, TEF, CHASEPAYMENTECH, BSITAU, BSBRADESCO= '1', '2', '3', '4', '5', '8', '11', '12'

PROCESSORS_CHOICES = (
    (TEST, 'Simulador de testes'),
    (REDECARD, 'Redecard'),
    (AMEX, 'Amex'),
    (CIELO, 'Cielo'),
    (TEF, 'TEF'),
    (CHASEPAYMENTECH, 'ChasePaymentech'),
    (BSITAU, 'BSItau'),
    (BSBRADESCO, 'BSBradesco'),
)
